@@ -4,7 +4,7 @@ from typing import Dict, Callable, Optional, Type, TypeVar, List
 
 import kubernetes
 from cachetools.func import lru_cache
-from kubernetes.client import ApiClient
+from kubernetes.client import ApiClient, V1OwnerReference
 from kubernetes.client.rest import ApiException
 
 from k8kat.auth.kube_broker import broker
@@ -184,6 +184,11 @@ class KatRes:
         self.reload()
     return condition_met
 
+  def owner_ref(self, target_kind: str) -> V1OwnerReference:
+    finder = lambda ref: ref.kind == target_kind
+    candidates = self.raw.metadata.owner_references
+    return next(filter(finder, candidates), None)
+
   def intel(self) -> List[IntelDict]:
     return []
 
