@@ -18,3 +18,8 @@ class PodMetricsDict(TypedDict):
 class NodeMetricsDict(TypedDict):
   usage: UsageDict
 
+
+class IntelDict(TypedDict):
+  type: str
+  status: str
+  message: str
